@@ -162,8 +162,11 @@ QString QGuiPlatformPlugin::styleName()
     case DE_KDE:
         stylename = QKde::kdeStyle();
         break;
+    case DE_CINNAMON:
+    case DE_CYGWIN:
     case DE_LXDE:
     case DE_MATE:
+    case DE_XFCE:
     case DE_GNOME: {
         QStringList availableStyles = QStyleFactory::keys();
         // Set QGtkStyle for GNOME if available
@@ -208,14 +211,27 @@ QString QGuiPlatformPlugin::systemIconThemeName()
 #ifndef QT_NO_STYLE_GTK
     result = QGtkStylePrivate::getIconThemeName();
 #endif
-    if (X11->desktopEnvironment == DE_GNOME && result.isEmpty()) {
-            result = QString::fromLatin1("gnome");
-    } else if (X11->desktopEnvironment == DE_MATE && result.isEmpty()) {
-            result = QString::fromLatin1("mate");
-    } else if (X11->desktopEnvironment == DE_LXDE && result.isEmpty()) {
-            result = QString::fromLatin1("nuoveXT2");
-    } else if (X11->desktopEnvironment == DE_KDE) {
-        result =  X11->desktopVersion >= 4 ? QString::fromLatin1("oxygen") : QString::fromLatin1("crystalsvg");
+    switch (X11->desktopEnvironment) {
+    case DE_GNOME:
+    case DE_CYGWIN:
+        result = QString::fromLatin1("Adwaita");
+    case DE_CINNAMON:
+        result = QString::fromLatin1("gnome");
+    case DE_LXDE:
+        result = QString::fromLatin1("nuoveXT2");
+    case DE_LXQT:
+        result = QString::fromLatin1("oxygen");
+    case DE_MATE:
+        result = QString::fromLatin1("menta");
+    case DE_XFCE:
+        result = QString::fromLatin1("Rodent");
+    case DE_KDE:
+        if (X11->desktopVersion >= 5)
+            result = QString::fromLatin1("breeze");
+        else if (X11->desktopVersion == 4)
+            result = QString::fromLatin1("oxygen");
+        else
+            result = QString::fromLatin1("crystalsvg");
         QSettings settings(QKde::kdeHome() + QLatin1String("/share/config/kdeglobals"), QSettings::IniFormat);
         settings.beginGroup(QLatin1String("Icons"));
         result = settings.value(QLatin1String("Theme"), result).toString();
